import { ApiDOMErrorOptions } from '@swagger-api/apidom-error';
import { ApiDOMStructuredError } from '@swagger-api/apidom-error';
import { Element as Element_2 } from '@swagger-api/apidom-core';

/**
 * @public
 */
export declare class CompilationRelativeJsonPointerError extends RelativeJsonPointerError {
    readonly nonNegativeIntegerPrefix: number;
    readonly indexManipulation?: number;
    readonly jsonPointerTokens?: string[];
    readonly hashCharacter?: boolean;
    constructor(message?: string, structuredOptions?: CompilationRelativeJsonPointerErrorOptions);
}

/**
 * @public
 */
export declare interface CompilationRelativeJsonPointerErrorOptions extends ApiDOMErrorOptions {
    readonly relativePointer: RelativeJsonPointer;
}

/**
 * @public
 */
export declare const compile: (relativeJsonPointer: RelativeJsonPointer) => string;

/**
 * Evaluates Relative JSON Pointer against ApiDOM fragment.
 * @public
 */
export declare const evaluate: <T extends Element_2, U extends Element_2>(relativePointer: string, currentElement: T, rootElement: U) => Element_2 | undefined;

/**
 * @public
 */
export declare class EvaluationRelativeJsonPointerError<T extends Element_2, U extends Element_2, V extends Element_2> extends RelativeJsonPointerError {
    readonly relativePointer: string;
    readonly currentElement: T;
    readonly rootElement: U;
    readonly cursorElement?: V;
    constructor(message?: string, structuredOptions?: EvaluationRelativeJsonPointerErrorOptions<T, U, V>);
}

/**
 * @public
 */
export declare interface EvaluationRelativeJsonPointerErrorOptions<T extends Element_2, U extends Element_2, V extends Element_2> extends ApiDOMErrorOptions {
    readonly relativePointer: string;
    readonly currentElement: T;
    readonly rootElement: U;
    readonly cursorElement?: V;
}

/**
 * @public
 */
export declare class InvalidRelativeJsonPointerError extends RelativeJsonPointerError {
    readonly relativePointer: string;
    constructor(message?: string, structuredOptions?: InvalidRelativeJsonPointerErrorOptions);
}

/**
 * @public
 */
export declare interface InvalidRelativeJsonPointerErrorOptions extends ApiDOMErrorOptions {
    readonly relativePointer: string;
}

/**
 * @public
 */
export declare const isRelativeJsonPointer: (value: any) => boolean;

/**
 * @public
 */
export declare const parse: (relativePointer: string) => RelativeJsonPointer;

/**
 * @public
 */
export declare type RelativeJsonPointer = {
    readonly nonNegativeIntegerPrefix: number;
    readonly indexManipulation?: number;
    readonly jsonPointerTokens?: string[];
    readonly hashCharacter?: boolean;
};

/**
 * @public
 */
export declare class RelativeJsonPointerError extends ApiDOMStructuredError {
}

export { }
